# Website build tools
This repo contains code for building encyclopedia websites that is used by
[DefElement](https://defelement.org)
and [the online encyclopedia of quadrature rules](https://quadraturerules.org).

## Installing

To install the latest release from PyPI, run:

```bash
pip install website-build-tools
```

To install the latest code from GitHub, run:

```bash
pip install git+https://github.com/DefElement/website-build-tools.git
```

